@@ -1,43 +1,43 @@
 package Catmandu::Importer::XLSX;
 
-our $VERSION = '0.07';
+our $VERSION = '0.09';
 
 use namespace::clean;
 use Catmandu::Sane;
 use Encode qw(decode);
-use Spreadsheet::XLSX;
+use Spreadsheet::ParseXLSX;
 use Spreadsheet::ParseExcel::Utility qw(int2col);
 use Moo;
 
 with 'Catmandu::Importer';
 
-has xlsx => (is => 'ro', builder => '_build_xlsx');
-has header => (is => 'ro', default => sub { 1 });
-has columns => (is => 'ro' , default => sub { 0 });
+has xlsx    => (is => 'ro', builder => '_build_xlsx');
+has header  => (is => 'ro', default => sub {1});
+has columns => (is => 'ro', default => sub {0});
 has fields => (
     is     => 'rw',
     coerce => sub {
         my $fields = $_[0];
-        if (ref $fields eq 'ARRAY') { return $fields }
-        if (ref $fields eq 'HASH')  { return [sort keys %$fields] }
+        if (ref $fields eq 'ARRAY') {return $fields}
+        if (ref $fields eq 'HASH') {return [sort keys %$fields]}
         return [split ',', $fields];
     },
 );
-has worksheet => (is => 'ro' , default => sub { 0 });
-has _n => (is => 'rw', default => sub { 0 });
-has _row_min => (is => 'rw');
-has _row_max => (is => 'rw');
-has _col_min => (is => 'rw');
-has _col_max => (is => 'rw');
+has worksheet => (is => 'ro', default => sub {0});
+has _n        => (is => 'rw', default => sub {0});
+has _row_min  => (is => 'rw');
+has _row_max  => (is => 'rw');
+has _col_min  => (is => 'rw');
+has _col_max  => (is => 'rw');
 
 sub BUILD {
     my $self = shift;
 
-    if ( $self->header ) {
-        if ( $self->fields ) {
+    if ($self->header) {
+        if ($self->fields) {
             $self->{_n}++;
         }
-        elsif ( $self->columns ) {
+        elsif ($self->columns) {
             $self->fields([$self->_get_cols]);
             $self->{_n}++;
         }
@@ -47,7 +47,7 @@ sub BUILD {
         }
     }
     else {
-        if ( !$self->fields || $self->columns ) {
+        if (!$self->fields || $self->columns) {
             $self->fields([$self->_get_cols]);
         }
     }
@@ -55,14 +55,16 @@ sub BUILD {
 
 sub _build_xlsx {
     my ($self) = @_;
-    my $xlsx = Spreadsheet::XLSX->new( $self->file ) or Catmandu::Error->throw( "could not parse file \"$self->{file}\"" );
+    my $parser = Spreadsheet::ParseXLSX->new();
+    my $xlsx   = $parser->parse($self->file)
+        or Catmandu::Error->throw(
+        "could not parse file \"$self->{file}\": " . $parser->error());
 
-    # process only first worksheet
-    $xlsx = $xlsx->{Worksheet}->[ $self->worksheet ] or Catmandu::Error->throw("worksheet $self->{worksheet} does not exist.");
-    $self->{_col_min} = $xlsx->{MinCol};
-    $self->{_col_max} = $xlsx->{MaxCol};
-    $self->{_row_min} = $xlsx->{MinRow};
-    $self->{_row_max} = $xlsx->{MaxRow};
+    $xlsx = $xlsx->worksheet($self->worksheet)
+        or Catmandu::Error->throw(
+        "worksheet $self->{worksheet} does not exist.");
+    ($self->{_row_min}, $self->{_row_max}) = $xlsx->row_range();
+    ($self->{_col_min}, $self->{_col_max}) = $xlsx->col_range();
     return $xlsx;
 }
 
@@ -73,10 +75,10 @@ sub generator {
             my @data = $self->_get_row();
             $self->{_n}++;
             my @fields = @{$self->fields()};
-            my %hash = map { 
+            my %hash   = map {
                 my $key = shift @fields;
-                defined $_  ? ($key => $_) : ()
-                } @data;
+                defined $_ ? ($key => $_) : ()
+            } @data;
             return \%hash;
         }
         return;
@@ -86,13 +88,13 @@ sub generator {
 sub _get_row {
     my ($self) = @_;
     my @row;
-    for my $col ( $self->_col_min .. $self->_col_max ) {
-        my $cell = $self->xlsx->{Cells}[$self->_n][$col];
+    for my $col ($self->_col_min .. $self->_col_max) {
+        my $cell = $self->xlsx->get_cell($self->_n, $col);
         if ($cell) {
-            push(@row, decode('UTF-8',$cell->{Val}));
+            push(@row, $cell->value());
         }
-        else{
-            push(@row, undef);            
+        else {
+            push(@row, undef);
         }
     }
     return @row;
@@ -101,25 +103,24 @@ sub _get_row {
 sub _get_cols {
     my ($self) = @_;
     my @row;
-    for my $col ( $self->_col_min .. $self->_col_max ) {
+    for my $col ($self->_col_min .. $self->_col_max) {
 
         if (!$self->header || $self->columns) {
-            push(@row,int2col($col));
+            push(@row, int2col($col));
         }
         else {
-            my $cell = $self->xlsx->{Cells}[$self->_n][$col];
+            my $cell = $self->xlsx->get_cell($self->_n, $col);
             if ($cell) {
-                push(@row, decode('UTF-8',$cell->{Val}));
+                push(@row, $cell->value());
             }
-            else{
-                push(@row, undef);            
+            else {
+                push(@row, undef);
             }
         }
     }
     return @row;
 }
 
-
 =head1 NAME
 
 Catmandu::Importer::XLSX - Package that imports XLSX files
@@ -147,8 +148,6 @@ Catmandu::Importer::XLSX - Package that imports XLSX files
 
 L<Catmandu> importer for XLSX files.
 
-Only the first worksheet from the Excel workbook is imported.
-
 =head1 METHODS
  
 This module inherits all methods of L<Catmandu::Importer> and by this
@@ -188,4 +187,4 @@ L<Catmandu::Importer>, L<Catmandu::Iterable>, L<Catmandu::Importer::CSV>, L<Catm
 
 =cut
 
-1;
\ No newline at end of file
+1;
